timings contains run times for a larger range of values
for the n argument.
timings_sort contains run times for sorting probabilities
with the given distributions.
break_even contains detailed run times for the analysis of
break-even points between the various implementations.